@@ -10,8 +10,6 @@
 
 NAN_METHOD(ReturnString) {
   NanScope();
-  char *buf = NanCString(args[0], NULL);
-  v8::Local<v8::String> s = NanNew<v8::String>(buf);
-  delete[] buf;
+  v8::Local<v8::String> s = NanNew<v8::String>(*NanUtf8String(args[0]));
   NanReturnValue(s);
 }
