@@ -1,9 +1,10 @@
 const test     = require('tap').test
-    , bindings = require('bindings')
-    , crypto   = require('crypto')
+    , testRoot = require('path').resolve(__dirname, '..')
+    , bindings = require('bindings')({ module_root: testRoot, bindings: 'bufferworkerpersistent' })
+    , crypto   = require('crypto');
 
 test('bufferworkerpersistent', function (t) {
-  var worker = bindings('bufferworkerpersistent').a
+  var worker = bindings.a
     , called = false
     , buf    = crypto.randomBytes(256)
     , bufHex = buf.toString('hex')
@@ -11,9 +12,9 @@ test('bufferworkerpersistent', function (t) {
   t.type(worker, 'function')
 
   setTimeout(function () {
-    t.ok(called)
+    t.ok(called, 'callback fired')
     t.end()
-  }, 300)
+  }, 500)
 
   worker(200, buf, function (_buf) {
     called = true
