@@ -1,5 +1,6 @@
 const test     = require('tap').test
-    , bindings = require('bindings');
+    , testRoot = require('path').resolve(__dirname, '..')
+    , bindings = require('bindings')({ module_root: testRoot, bindings: 'multifile' });
 
 // same as fromv8string test but split over multiple compile units
 // just to test that there aren't any conflicts from including nan.h
@@ -7,7 +8,7 @@ const test     = require('tap').test
 test('multifile', function (t) {
   t.plan(2);
 
-  var r = bindings('multifile').r
+  var r = bindings.r
   t.type(r, 'function');
   t.equal(r('a string value'), 'a string value');
 });
