@@ -1,10 +1,11 @@
 const test     = require('tap').test
-    , bindings = require('bindings');
+    , testRoot = require('path').resolve(__dirname, '..')
+    , bindings = require('bindings')({ module_root: testRoot, bindings: 'weak' });
 
 test('weak', function (t) {
   t.plan(3);
 
-  var weak = bindings('weak');
+  var weak = bindings;
   t.type(weak.hustle, 'function');
 
   function f() {
